=======
History
=======

0.2.1 (2017-12-03)
------------------

* Updated to h2 3.0 (Contributed by Arthur Darcet and Peter Wu)
* Dropped support for Python 3.3

0.1.0 (2016-2-6)
----------------

* First release on PyPI.
